from __future__ import unicode_literals

from django.conf import settings
from django.contrib.contenttypes.fields import GenericForeignKey
from django.contrib.contenttypes.models import ContentType
from django.db import models



class Like(models.Model):

    user = models.ForeignKey(settings.AUTH_USER_MODEL, related_name='likes')
    content_type = models.ForeignKey(ContentType, on_delete=models.CASCADE)
    object_id = models.PositiveIntegerField()
    content_object = GenericForeignKey('content_type', 'object_id')



# _*_ coding: utf-8 _*_
from distutils.core import setup
from setuptools import find_packages

setup(
    name='django-liked',
    version='1.0.0',
    author='Amyth Arora',
    author_email='mail@amythsingh.com',
    packages=find_packages(),
    url='https://github.com/amyth/django-liked',
    license='MIT License',
    description='A django likes app',
    long_description='Django Liked is a generic like dislike application that '\
        'built on django 1.10 using the contenttypes framework to create likes'\
        'for any models in your django project',
    zip_safe=False,
)
